@@ -22,7 +22,7 @@
 #'   which is no more than `range` times the interquartile range from the box.
 #'   Defaults to `1.0`.
 #' @param what A string specifying what the function should return. Choices are
-#'   `"plot"`, `"stats"` or `"plot+stats"`. Defaults to `"plot"`.
+#'   `"plot"`, `"stats"` or `"plot+stats"`. Defaults to `"stats"`.
 #' @param ... Unused here.
 #'
 #' @return If `what` contains `stats`, a list containing the computed statistics
@@ -41,7 +41,7 @@ boxplot.fdawarp <- function(x,
                             variability_type = c("amplitude", "phase"),
                             alpha = 0.05,
                             range = 1.0,
-                            what = c("plot", "stats", "plot+stats"),
+                            what = c("stats", "plot", "plot+stats"),
                             ...) {
   variability_type <- rlang::arg_match(variability_type)
   what <- rlang::arg_match(what)
@@ -358,7 +358,7 @@ ampbox_data <- function(warp_median, alpha = 0.05, ka = 1) {
   lower_dis <- sqrt(trapz(time, (lower_q - qmedian)^2))
   whisker_dis <- max(c(upper_dis, lower_dis))
 
-  # indentify amplitude outliers
+  # identify amplitude outliers
   outlier_index <- c()
   for (i in 1:N) {
     if (dy[dy_ordering[N + 1 - i]] > whisker_dis)
@@ -367,7 +367,7 @@ ampbox_data <- function(warp_median, alpha = 0.05, ka = 1) {
       break
   }
 
-  # identify ampitude extremes
+  # identify amplitude extremes
   distance_to_upper <- rep(Inf, N)
   distance_to_lower <- rep(Inf, N)
   out_50_CR <- setdiff(setdiff(1:N, CR_50), outlier_index)
